@@ -2,26 +2,13 @@
  * Copyright (c) 2007 Mockito contributors
  * This program is made available under the terms of the MIT License.
  */
-
 package org.mockitousage.matchers;
 
-import java.math.BigDecimal;
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.List;
-import java.util.RandomAccess;
-import java.util.regex.Pattern;
-import org.junit.Test;
-import org.mockito.Mockito;
-import org.mockito.exceptions.verification.WantedButNotInvoked;
-import org.mockito.exceptions.verification.opentest4j.ArgumentsAreDifferent;
-import org.mockitousage.IMethods;
-import org.mockitoutil.TestBase;
-
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotSame;
 import static org.junit.Assert.fail;
-import static org.assertj.core.api.Assertions.assertThat;
 import static org.mockito.AdditionalMatchers.and;
 import static org.mockito.AdditionalMatchers.aryEq;
 import static org.mockito.AdditionalMatchers.cmpEq;
@@ -33,8 +20,8 @@ import static org.mockito.AdditionalMatchers.leq;
 import static org.mockito.AdditionalMatchers.lt;
 import static org.mockito.AdditionalMatchers.not;
 import static org.mockito.AdditionalMatchers.or;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.ArgumentMatchers.nullable;
-import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.anyBoolean;
 import static org.mockito.Mockito.anyByte;
@@ -43,7 +30,6 @@ import static org.mockito.Mockito.anyDouble;
 import static org.mockito.Mockito.anyFloat;
 import static org.mockito.Mockito.anyInt;
 import static org.mockito.Mockito.anyLong;
-import static org.mockito.Mockito.anyObject;
 import static org.mockito.Mockito.anyShort;
 import static org.mockito.Mockito.anyString;
 import static org.mockito.Mockito.contains;
@@ -60,6 +46,19 @@ import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
+import java.math.BigDecimal;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.RandomAccess;
+import java.util.regex.Pattern;
+
+import org.junit.Test;
+import org.mockito.ArgumentMatchers;
+import org.mockito.Mockito;
+import org.mockito.exceptions.verification.WantedButNotInvoked;
+import org.mockito.exceptions.verification.opentest4j.ArgumentsAreDifferent;
+import org.mockitousage.IMethods;
+import org.mockitoutil.TestBase;
 
 @SuppressWarnings("unchecked")
 public class MatchersTest extends TestBase {
@@ -285,9 +284,7 @@ public class MatchersTest extends TestBase {
         when(mock.oneArg(anyInt())).thenReturn("5");
         when(mock.oneArg(anyLong())).thenReturn("6");
         when(mock.oneArg(anyShort())).thenReturn("7");
-        when(mock.oneArg((String) anyObject())).thenReturn("8");
-        when(mock.oneArg(Mockito.<Object>anyObject())).thenReturn("9");
-        when(mock.oneArg(any(RandomAccess.class))).thenReturn("10");
+        when(mock.oneArg(any(RandomAccess.class))).thenReturn("8");
 
         assertEquals("0", mock.oneArg(true));
         assertEquals("0", mock.oneArg(false));
@@ -299,12 +296,8 @@ public class MatchersTest extends TestBase {
         assertEquals("5", mock.oneArg(1));
         assertEquals("6", mock.oneArg(1L));
         assertEquals("7", mock.oneArg((short) 1));
-        assertEquals("8", mock.oneArg("Test"));
 
-        assertEquals("9", mock.oneArg(new Object()));
-        assertEquals("9", mock.oneArg(new HashMap()));
-
-        assertEquals("10", mock.oneArg(new ArrayList()));
+        assertEquals("8", mock.oneArg(new ArrayList()));
     }
 
     @Test
@@ -326,59 +319,70 @@ public class MatchersTest extends TestBase {
 
     @Test
     public void should_use_smart_equals_for_arrays() throws Exception {
-        //issue 143
-        mock.arrayMethod(new String[]{"one"});
-        verify(mock).arrayMethod(eq(new String[]{"one"}));
-        verify(mock).arrayMethod(new String[]{"one"});
+        // issue 143
+        mock.arrayMethod(new String[] {"one"});
+        verify(mock).arrayMethod(eq(new String[] {"one"}));
+        verify(mock).arrayMethod(new String[] {"one"});
     }
 
     @Test
     public void should_use_smart_equals_for_primitive_arrays() throws Exception {
-        //issue 143
-        mock.objectArgMethod(new int[]{1, 2});
-        verify(mock).objectArgMethod(eq(new int[]{1, 2}));
-        verify(mock).objectArgMethod(new int[]{1, 2});
+        // issue 143
+        mock.objectArgMethod(new int[] {1, 2});
+        verify(mock).objectArgMethod(eq(new int[] {1, 2}));
+        verify(mock).objectArgMethod(new int[] {1, 2});
     }
 
-    @Test(expected = ArgumentsAreDifferent.class)
-    public void array_equals_should_throw_ArgumentsAreDifferentException_for_non_matching_arguments() {
+    @SuppressWarnings("ReturnValueIgnored")
+    @Test
+    public void
+            array_equals_should_throw_ArgumentsAreDifferentException_for_non_matching_arguments() {
         List<Object> list = Mockito.mock(List.class);
 
         list.add("test"); // testing fix for issue 20
-        list.contains(new Object[]{"1"});
+        list.contains(new Object[] {"1"});
 
-        Mockito.verify(list).contains(new Object[]{"1", "2", "3"});
+        assertThatThrownBy(
+                        () -> {
+                            Mockito.verify(list).contains(new Object[] {"1", "2", "3"});
+                        })
+                .isInstanceOf(ArgumentsAreDifferent.class)
+                .hasMessageContainingAll(
+                        "Argument(s) are different! Wanted:",
+                        "list.contains([\"1\", \"2\", \"3\"]);",
+                        "Actual invocations have different arguments:",
+                        "list.add(\"test\");");
     }
 
     @Test
     public void array_equals_matcher() {
-        when(mock.oneArray(aryEq(new boolean[]{true, false, false}))).thenReturn("0");
-        when(mock.oneArray(aryEq(new byte[]{1}))).thenReturn("1");
-        when(mock.oneArray(aryEq(new char[]{1}))).thenReturn("2");
-        when(mock.oneArray(aryEq(new double[]{1}))).thenReturn("3");
-        when(mock.oneArray(aryEq(new float[]{1}))).thenReturn("4");
-        when(mock.oneArray(aryEq(new int[]{1}))).thenReturn("5");
-        when(mock.oneArray(aryEq(new long[]{1}))).thenReturn("6");
-        when(mock.oneArray(aryEq(new short[]{1}))).thenReturn("7");
-        when(mock.oneArray(aryEq(new String[]{"Test"}))).thenReturn("8");
-        when(mock.oneArray(aryEq(new Object[]{"Test", new Integer(4)}))).thenReturn("9");
+        when(mock.oneArray(aryEq(new boolean[] {true, false, false}))).thenReturn("0");
+        when(mock.oneArray(aryEq(new byte[] {1}))).thenReturn("1");
+        when(mock.oneArray(aryEq(new char[] {1}))).thenReturn("2");
+        when(mock.oneArray(aryEq(new double[] {1}))).thenReturn("3");
+        when(mock.oneArray(aryEq(new float[] {1}))).thenReturn("4");
+        when(mock.oneArray(aryEq(new int[] {1}))).thenReturn("5");
+        when(mock.oneArray(aryEq(new long[] {1}))).thenReturn("6");
+        when(mock.oneArray(aryEq(new short[] {1}))).thenReturn("7");
+        when(mock.oneArray(aryEq(new String[] {"Test"}))).thenReturn("8");
+        when(mock.oneArray(aryEq(new Object[] {"Test", new Integer(4)}))).thenReturn("9");
 
-        assertEquals("0", mock.oneArray(new boolean[]{true, false, false}));
-        assertEquals("1", mock.oneArray(new byte[]{1}));
-        assertEquals("2", mock.oneArray(new char[]{1}));
-        assertEquals("3", mock.oneArray(new double[]{1}));
-        assertEquals("4", mock.oneArray(new float[]{1}));
-        assertEquals("5", mock.oneArray(new int[]{1}));
-        assertEquals("6", mock.oneArray(new long[]{1}));
-        assertEquals("7", mock.oneArray(new short[]{1}));
-        assertEquals("8", mock.oneArray(new String[]{"Test"}));
-        assertEquals("9", mock.oneArray(new Object[]{"Test", new Integer(4)}));
+        assertEquals("0", mock.oneArray(new boolean[] {true, false, false}));
+        assertEquals("1", mock.oneArray(new byte[] {1}));
+        assertEquals("2", mock.oneArray(new char[] {1}));
+        assertEquals("3", mock.oneArray(new double[] {1}));
+        assertEquals("4", mock.oneArray(new float[] {1}));
+        assertEquals("5", mock.oneArray(new int[] {1}));
+        assertEquals("6", mock.oneArray(new long[] {1}));
+        assertEquals("7", mock.oneArray(new short[] {1}));
+        assertEquals("8", mock.oneArray(new String[] {"Test"}));
+        assertEquals("9", mock.oneArray(new Object[] {"Test", new Integer(4)}));
 
-        assertEquals(null, mock.oneArray(new Object[]{"Test", new Integer(999)}));
-        assertEquals(null, mock.oneArray(new Object[]{"Test", new Integer(4), "x"}));
+        assertEquals(null, mock.oneArray(new Object[] {"Test", new Integer(999)}));
+        assertEquals(null, mock.oneArray(new Object[] {"Test", new Integer(4), "x"}));
 
-        assertEquals(null, mock.oneArray(new boolean[]{true, false}));
-        assertEquals(null, mock.oneArray(new boolean[]{true, true, false}));
+        assertEquals(null, mock.oneArray(new boolean[] {true, false}));
+        assertEquals(null, mock.oneArray(new boolean[] {true, true, false}));
     }
 
     @Test
@@ -454,14 +458,14 @@ public class MatchersTest extends TestBase {
 
     @Test
     public void null_matcher_for_primitive_wrappers() {
-        when(mock.forBoolean(isNull(Boolean.class))).thenReturn("ok");
-        when(mock.forInteger(isNull(Integer.class))).thenReturn("ok");
-        when(mock.forLong(isNull(Long.class))).thenReturn("ok");
-        when(mock.forByte(isNull(Byte.class))).thenReturn("ok");
-        when(mock.forShort(isNull(Short.class))).thenReturn("ok");
-        when(mock.forCharacter(isNull(Character.class))).thenReturn("ok");
-        when(mock.forDouble(isNull(Double.class))).thenReturn("ok");
-        when(mock.forFloat(isNull(Float.class))).thenReturn("ok");
+        when(mock.forBoolean(ArgumentMatchers.<Boolean>isNull())).thenReturn("ok");
+        when(mock.forInteger(ArgumentMatchers.<Integer>isNull())).thenReturn("ok");
+        when(mock.forLong(ArgumentMatchers.<Long>isNull())).thenReturn("ok");
+        when(mock.forByte(ArgumentMatchers.<Byte>isNull())).thenReturn("ok");
+        when(mock.forShort(ArgumentMatchers.<Short>isNull())).thenReturn("ok");
+        when(mock.forCharacter(ArgumentMatchers.<Character>isNull())).thenReturn("ok");
+        when(mock.forDouble(ArgumentMatchers.<Double>isNull())).thenReturn("ok");
+        when(mock.forFloat(ArgumentMatchers.<Float>isNull())).thenReturn("ok");
 
         assertEquals("ok", mock.forBoolean(null));
         assertEquals("ok", mock.forInteger(null));
@@ -511,6 +515,14 @@ public class MatchersTest extends TestBase {
         assertEquals(null, mock.oneArg("blah"));
     }
 
+    @Test
+    public void matches_Pattern_matcher_in_subregion() {
+        when(mock.oneArg(matches(Pattern.compile("[a-z]")))).thenReturn("1");
+
+        assertEquals("1", mock.oneArg("3a45"));
+        assertEquals(null, mock.oneArg("3445"));
+    }
+
     @Test
     public void contains_matcher() {
         when(mock.oneArg(contains("ell"))).thenReturn("1");
@@ -608,7 +620,7 @@ public class MatchersTest extends TestBase {
     public void nullable_matcher() throws Exception {
         // imagine a Stream.of(...).map(c -> mock.oneArg(c))...
         mock.oneArg((Character) null);
-        mock.oneArg(Character.valueOf('€'));
+        mock.oneArg(Character.valueOf('\u20AC'));
 
         verify(mock, times(2)).oneArg(nullable(Character.class));
     }
