@@ -6,15 +6,12 @@ plugins {
 
 description = "End-to-end tests for automatic registration of MockitoExtension."
 
-java {
-    sourceCompatibility = JavaVersion.VERSION_1_8
-}
 dependencies {
-    testCompile(project(":junit-jupiter"))
-    testCompile(library("assertj"))
-    testCompile(library("junitPlatformLauncher"))
-    testCompile(library("junitJupiterApi"))
-    testRuntime(library("junitJupiterEngine"))
+    testImplementation(project(":junit-jupiter"))
+    testImplementation(library("assertj"))
+    testImplementation(library("junitPlatformLauncher"))
+    testImplementation(library("junitJupiterApi"))
+    testRuntimeOnly(library("junitJupiterEngine"))
 }
 
 tasks.named<Test>("test") {
